@@ -1,6 +1,6 @@
 package Test::Toolbox;
 use strict;
-use String::Util ':all';
+# use String::Util ':all';
 use Carp 'croak';
 use Test::Builder::Module;
 use Cwd 'abs_path';
@@ -10,7 +10,8 @@ use Cwd 'abs_path';
 # use Debug::ShowStuff::ShowVar;
 
 # version
-our $VERSION = '0.1';
+our $VERSION = '0.2';
+
 
 
 #------------------------------------------------------------------------------
@@ -131,6 +132,7 @@ our (@EXPORT);
 #------------------------------------------------------------------------------
 
 
+
 #------------------------------------------------------------------------------
 # globals
 #
@@ -192,6 +194,8 @@ sub go_script_dir {
 #------------------------------------------------------------------------------
 
 
+
+
 #------------------------------------------------------------------------------
 # rtplan
 #
@@ -471,6 +475,7 @@ sub rtcomp {
 #------------------------------------------------------------------------------
 
 
+
 #------------------------------------------------------------------------------
 # rtelcount
 #
@@ -598,6 +603,7 @@ sub rtarr {
 #------------------------------------------------------------------------------
 
 
+
 #------------------------------------------------------------------------------
 # rthash
 #
@@ -643,7 +649,7 @@ sub rthash {
 	foreach my $key (keys %should) {
 		# if key doesn't exist
 		if (exists $have{$key}) {
-			if (neundef $have{$key}, $should{$key}) {
+			if (neqq($have{$key}, $should{$key})) {
 				push @wrong,
 					'have:   ' . showval($have{$key}) . "\n" .
 					'should: ' . showval($should{$key});
@@ -677,6 +683,7 @@ sub rthash {
 #------------------------------------------------------------------------------
 
 
+
 #------------------------------------------------------------------------------
 # rtisa
 #
@@ -1063,6 +1070,52 @@ sub rteval {
 # private methods
 #
 
+
+#------------------------------------------------------------------------------
+# showval
+#
+sub showval {
+	my ($val) = @_;
+	
+	# if not defined, return [undef]
+	if (! defined $val) {
+		return '[undef]';
+	}
+	
+	# else just return value
+	return $val;
+}
+#
+# showval
+#------------------------------------------------------------------------------
+
+
+#------------------------------------------------------------------------------
+# eqq, neqq
+#
+sub eqq {
+	my ($str1, $str2) = @_;
+	
+	# if both defined
+	if ( defined($str1) && defined($str2) )
+		{ return $str1 eq $str2 }
+	
+	# if neither are defined 
+	if ( (! defined($str1)) && (! defined($str2)) )
+		{ return 1 }
+	
+	# only one is defined, so return false
+	return 0;
+}
+
+sub neqq {
+	return eqq(@_) ? 0 : 1;
+}
+#
+# eqq, neqq
+#------------------------------------------------------------------------------
+
+
 #------------------------------------------------------------------------------
 # ok_private
 # private method
@@ -1194,24 +1247,6 @@ sub comp_sorter {
 
 
 
-#------------------------------------------------------------------------------
-# showval
-#
-sub showval {
-	my ($val) = @_;
-	
-	# if not defined, return [undef]
-	if (! defined $val) {
-		return '[undef]';
-	}
-	
-	# else just return value
-	return $val;
-}
-#
-# showval
-#------------------------------------------------------------------------------
-
 
 #
 # private methods
@@ -1250,6 +1285,11 @@ Version: 0.01
 
 Initial release.
 
+=item * Version 0.02 Aug 23, 2016
+
+Fixed dependency problem. Should not have been using String::Util.
+
+
 =back
 
 =cut
